@@ -1,3 +1,4 @@
+import chunk
 import enum
 import os
 import sys
@@ -8,7 +9,6 @@ import requests
 from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
-from itertools import islice
 
 OPERATOR_ID = AccountId.fromString(os.getenv("OPERATOR_ID"))
 OPERATOR_PRIVATE_KEY = PrivateKey.fromString(os.getenv("OPERATOR_PRIVATE_KEY"))
@@ -36,9 +36,10 @@ class Network3Medusa():
             info = query.execute(self.client)
             print("File size according to `FileInfoQuery`: ", info.size)
         else:
-            json_dict = json.loads(raw_json)
+            json_dict = json.load(raw_json)
+            chunkSize = 6000
             first = True
-            for item in self.chunks(json_dict, 3):
+            for item in range(0,len(json_dict), chunkSize):
                 print(item)
                 if first:
                     first = False
@@ -51,11 +52,6 @@ class Network3Medusa():
             if WEBEX_ROOM:
                 self.send_webex_notification()
 
-    def chunks(self, data, SIZE=6000):
-        it = iter(data)
-        for i in range(0, len(data), SIZE):
-            yield {k:data[k] for k in islice(it, SIZE)}
-
     def py2output(self):
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
 
